Supreme Court of Georgia

date and print
| Print this page
# 2015 Opinion and Summaries JANUARY 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. January 20, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14A1286, S14A1287. BABBAGE v. THE STATE (two cases) S14A1293. FUNCK v. THE STATE S14A1296. DURHAM v. THE STATE S14A1347. THE STATE v. COLVARD S14A1369. KITCHENS v. THE STATE S14A1371. WALLACE v. THE STATE S14A1409. TURNER v. THE STATE S14A1411. RIVERS v. THE STATE S14A1431. GRISSOM v. THE STATE S14A1442, S14A1443. NWAKANMA v. THE STATE (two cases) S14A1485. GRIFFIN v. THE STATE S14A1522. RHODES v. THE STATE S14A1570. McNEELY v. THE STATE S14A1706. ALLEN v. THE STATE S14A1713. STUCKEY v. STUCKEY et al. S14F1754. GUERRERO v. GUERRERO S14A1769. WHITING v. THE STATE S14F1887. GROVE v. GROVE S14Y1387. IN THE MATTER OF TANYA YVETTE BROCKINGTON S14Y1732. IN THE MATTER OF MAURICE BROWN S15Z0571. IN THE MATTER OF CHARLES HOUSTON RICHARDS, JR. FEBRUARY 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. February 2, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14A1278. ROSS v. THE STATE S14A1406. THOMPSON et al. v. BLACKWELL et al., EXECUTRIXES S14A1482. STEWART v. THE STATE S14A1525. WETHERINGTON v. THE STATE S14A1531. BRYANT v. THE STATE S14A1656. REYNOLDS v. REYNOLDS S14A1657. THE STATE v. SIMS S14A1679. REDDING v. THE STATE S14A1722. DEVAUGHN v. THE STATE S14A1882. WHITFIELD v. CITY OF ATLANTA et al. S14A1908, S14A1910. STUBBLEFIELD et al. v. STUBBLEFIELD et al. S14A1918. THOMAS v. THE STATE S14A1921. RAVENELL v. RAVENELL S14A1933. JOHNSON v. THE STATE S15Y0003. IN THE MATTER OF ROBERT T. THOMPSON, JR. S15Y0372. IN THE MATTER OF RAND J. CSEHY February 16, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G0619. CITY OF ATLANTA et al. v. MITCHAM S14G0753. PRIMAS v. CITY OF MILLEDGEVILLE S14G1005. PARKER v. THE STATE S14A1331. GLENN v. THE STATE S14P1344. SPEARS v. THE STATE S14A1359. KOSTURI v. THE STATE S14A1370. LEEKS v. THE STATE S14A1372. ANDERSON v. THE STATE S14A1419. HITES v. THE STATE S14A1471. THE STATE v. CUSACK S14A1478. SALES v. THE STATE S14A1524. SPRIGGS v. THE STATE S14A1685. CLARK v. THE STATE S14A1703. BUN v. THE STATE S14A1705. CORVI v. THE STATE S14A1749. JONES v. THE STATE S14A1892. HAMILTON STATE BANK v. NELSON et al. S14A1937. WILLIAMS v. THE STATE S15A0256. BATEMAN, PROPOUNDER v. SCROGGINS et al., CAVEATORS S14Y0700. IN THE MATTER OF JOHN FLOYD WOODHAM S14Y1542, S14Y1543. IN THE MATTER OF DOUGLAS GRANT EXLEY (two cases) S15Y0021, S15Y0022. IN THE MATTER OF RODD WALTON (two cases) S15Y0084. IN THE MATTER OF LYLE VINCENT ANDERSON S15Y0285. IN THE MATTER OF WESLEY KENT HILL MARCH 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. March 2, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G0603. KIGHT v. MCG HEALTH, INC. S14A1329. THE STATE v. MOBLEY S14A1342. MCDONALD v. THE STATE S14A1365. BRADSHAW v. THE STATE S14A1701. BLACK v. THE STATE S14A1702. JONES v. THE STATE S14A1824. INDIA-AMERICAN CULTURAL ASSOCIATION, INC v. iLINK PROFESSIONALS, INC. S14A1870. KANITRA v. CITY OF GREENSBORO et al. S14A1872. GOMILLION v. THE STATE S14A1925. HEARD v. THE STATE S15A0367. VCARE, LLC v. FIVE DIAMONDS, LLC et al. S14Y1825. IN THE MATTER OF JEFFREY L. SAKAS S15Y0512. IN THE MATTER OF JOSEPH CITRON March 16, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G0591. THE STATE v. LAMPL S14G0622. HUGHES v. THE STATE S14A1314. SANDERS v. RILEY, ADMINISTRATOR S14A1336. CORDERO v. THE STATE S14A1418. JEFFREY v. THE STATE S14A1497. ROBERTS v. THE STATE S14A1507. GREENE COUNTY DEVELOPMENT AUTHORITY et al. v. STATE OF GEORGIA et al. S14A1658. COOPER v. THE STATE S14A1669, S14A1673. NEAL v. HIBBARD (two cases) S14A1715. SMITH v. THE STATE S14A1874. COTTRELL et al. v. ATLANTA DEVELOPMENT AUTHORITY, d/b/a INVEST ATLANTA et al. S14A1884. ALLEN v. THE STATE S13Y0322. IN THE MATTER OF MURBLE ANITA WRIGHT March 27, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G0919. GALA et al. v. FISHER et al. S14A1352. HILL v. WILLIAMS, WARDEN S14A1373. TAYLOR v. THE STATE S14A1375, S14X1376. THE STATE v. CHULPAYEV (and vice versa) S14A1430. ALLEN v. THE STATE S14A1493. SJN PROPERTIES, LLC. v. FULTON COUNTY BOARD OF ASSESSORS et al. S14A1532. WOODARD v. THE STATE S14A1625. WILLIAMS v. THE STATE S14A1646. HARVEY v. THE STATE S14A1652. CHAN v. ELLIS S14A1797. FAVORS v. THE STATE S14A1840. DAUGHTRY v. THE STATE S14A1914. MOSLEY v. LANCASTER et al. APRIL 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. April 20, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1891. LEGACY ACADEMY, INC., et al. v. MAMILOVE, LLC et al. S15A0037. KASS v. STATE 6-1-2015 Substitute opinion issued. S15A0041. POLLARD v. POLLARD S15A0045. TEPANCA v. THE STATE S15A0110. CORDOVA, a/k/a CORDOBA v. THE STATE S15A0135, S15A0251. MADGE v. SAVANNAH-CHATHAM COUNTY PUBLIC SCHOOL DISTRICT et al. (two cases) S15A0147, S15X0148. DANFORTH, WARDEN v. CHAPMAN (and vice versa) S15A0316. FREEMAN v. STATE S15A0396. TORRES v. THE STATE S15Q0418. PIEDMONT OFFICE REALTY TRUST, INC., f/k/a WELLS REAL ESTATE INVESTMENT TRUST, INC. v. XL SPECIALTY INSURANCE COMPANY S15A0493. WILCHER v. McCONNELL, JUDGE et al. S15A0507. BADEN, WARDEN v. OCHOA-HERNANDEZ S15A0513. BROWN et al. v. HAMILTON, EXECUTOR S15Y0057, S15Y0058, S15Y0059, S15Y0060. IN THE MATTER OF TRACEY DAWN GIBSON (4 cases) S15Y0827. IN THE MATTER OF WILSON R. SMITH MAY 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. May 11, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1184. ESTATE OF CASON J. CALLAWAY, JR. v. GARNER et al. S14G1223. BOSTICK v. CMM PROPERTIES, INC. et al. S14G1762. ALEXANDER v. THE STATE S14G1775. OLIVER et al. v. McDADE et al. 7-16-2015 Substitute opinion issued. S15A0093. BUCKNER v. BARROW, WARDEN S15A0106. MIMS v. MIMS S15A0189. HENRY v. THE STATE S15Q0286. FCCI INSURANCE COMPANY. v. McLENDON ENTERPRISES, INC. et al. S15A0299. PRICE v. THE STATE S15A0308. McLEAN v. THE STATE S15A0340. WILSON v. THE STATE S15A0341. LAMAR v. THE STATE S15A0362, S15A0641. McHUGH FULLER LAW GROUP, PLLC v. PRUITTHEALTH-TOCCOA, LLC (two cases) S15A0370. McLEOD v. THE STATE S15A0421. MANN v. THE STATE S15A0450. HAGER v. THE STATE S15A0532. GOLDMAN v. JOHNSON, JUDGE S15A0573. MARLOWE v. MARLOWE S15A0578. DUGGER v. THE STATE S15A0589. GUTHRIDGE v. THE STATE S15A0612. TAYLOR v. THE STATE S15A0613. BESSENT v. THE STATE S15Y0228, S15Y0229. IN THE MATTER OF ROBERT GIST (two cases) S15Y1040. IN THE MATTER OF KIMBERLY L. COPELAND JUNE 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. June 1, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1061. THE STATE v. JONES S14G1202. CONSIDINE v. MURPHY et al. S14G1628. THE STATE v. EASTER S14G1878. TRAVELERS HOME & MARINE INSURANCE COMPANY v. CASTELLANOS S15F0039. PARTRIDGE v. PARTRIDGE S15A0040. TRIMBLE v. THE STATE S15A0139. DYAL v. THE STATE S15A0202. GOOCH v. GOOCH S15A0260. CHATMAN, WARDEN v. WALKER S15A0281. SMITH, WARDEN v. MAGNUSON S15A0296. SMITH v. THE STATE S15A0310. WILLIAMS v. THE STATE S15A0319. WHITE v. THE STATE S15A0355. THE STATE v. SUTTON S15A0379. NORWOOD v. THE STATE S15F0401. MALLARD v. MALLARD S15A0404. AIKENS v. THE STATE S15A0405. NORRED v. THE STATE S15A0406. LAND USA, LLC v. GEORGIA POWER COMPANY S15A0447. CROSDALE v. THE STATE S15A0463, S15A0464. BALLARD v. THE STATE, SOUN v. THE STATE (two cases) S15A0590. COTTON v. THE STATE S15A0591. DAUGHTIE v. THE STATE S15A0614. SMITH v. THE STATE S13Y0736, S14Y0892. IN THE MATTER OF ERIC C. LANG (two cases) S15Y0830. IN THE MATTER OF DAVID P. RACHEL S15Y0968. IN THE MATTER OF WILLIAM F. HEITMANN, III S15Y1102. IN THE MATTER OF CHARLES B. MERRILL, JR. S15Y1117. IN THE MATTER OF NEVILLE TREVOR FRANCIS June 15, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1161. KAUTZ, MAYOR v. POWELL et al. S14G1632. BOWDEN v. THE MEDICAL CENTER, INC. S14G1767. THE STATE v. FROST S14G1780, S14G1781. TURNER v. GEORGIA RIVER NETWORK et al., GRADY COUNTY BOARD OF COMMISSIONERS v. GEORGIA RIVER NETWORK et al. S14G1862. BAC HOME LOANS SERVICING, L.P., f/k/a COUNTRYWIDE HOME LOANS SERVICING v. WEDEREIT S15A0011. NEUMAN v. THE STATE S15A0103. EVANS v. GEORGIA BUREAU OF INVESTIGATION S15A0117. LUE, MAYOR v. EADY et al. 6-15-2015 Substitute opinion issued. S15A0146. OASIS GOODTIME EMPORIUM I, INC., d/b/a OASIS et al. v. CITY OF DORAVILLE et al. S15A0183, S15X0184. TAFEL v. LION ANTIQUE CARS & INVESTMENTS, INC., a/k/a LION ANTIQUE INVESTMENTS & CONSULTING SERVICES, INC. (and vice versa) S15A0309. FERGUSON v. THE STATE S15A0504. POWERS v. THE STATE S15A0586. MOHAMUD v. THE STATE S15A0588. HUMPHREY v. THE STATE S15A0600, S15A0601. POWELL v. THE STATE (two cases) S15A1076. MADGE v. SAVANNAH-CHATHAM COUNTY PUBLIC SCHOOL DISTRICT et al. S15Y0878. IN THE MATTER OF PERRIN BOWIE LOVETT S15Y0904, S15Y0905. IN THE MATTER OF MELISSA JILL STARLING S15Y1181. IN THE MATTER OF JAMES ALAN LANGLAIS June 22, 2015 S13Y1788. IN THE MATTER OF MICHAEL F. GREENE June 29, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1149. BHARADIA v. THE STATE 7-27-2015 Substitute opinion issued. S14G1173. ESHLEMAN v. KEY S14G1225. MCLEOD v. CLEMENTS S14G1539. THE STATE v. SPRINGER S14G1811. FLEMING v. THE STATE S14G1868, S14G1893, S14G1895. PHILLIPS et al. v. HARMON et al. (three cases) S15A0032. WHATLEY v. THE STATE S15F0064. STONE v. STONE et al. S15A0097. HILLMAN v. JOHNSON S15A0142, S15X0143. DAVIS v. VCP SOUTH, LLC et al. (and vice versa) S15A0182. SIMS v. THE STATE S15A0277, S15A0278, S15A0279. SAVAGE v. STATE OF GEORGIA et al. (three cases) S15A0335, S15A0336. REEVES et al. v. WEBB et al. (two cases) S15A0344. O'CONNELL v. THE STATE S15A0395. JOHNSON, EXECUTOR. v. ROGERS S15A0430. PENA v. THE STATE S15A0488. MORRIS v. THE STATE S15A0489. ELBERT COUNTY et al. v. SWEET CITY LANDFILL, LLC., et al. 7-10-2015 Substitute opinion issued. S15A0521. JONES v. BOONE S15A0587. DAILEY v. THE STATE S15A0624. MARSHALL v. THE STATE JULY 2015 DISCLAIMER: These opinions are subject to the parties' motion for reconsideration, the Court's reconsideration, and editorial changes made by the Reporter of Decisions. An opinion designated as "Final Copy" is the Supreme Court's official opinion as published in the advance sheets. Please Note: Adobe Acrobat Reader is necessary to read the following opinions. You may download Adobe Acrobat Reader here if necessary. Thank you. July 6, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1778. ZALDIVAR v. PRICKETT et al. 7-27-2015 Substitute opinion issued. S14G1876. VININGS BANK v. BRASFIELD & GORRIE, LLC S15A0243. RAI v. THE STATE S15A0244. STEIS v. STEIS S15A0403. MYERS, EXECUTOR v. MYERS S15A0534. ROMANO v. THE STATE S14Y1306, S14Y1307. IN THE MATTER OF WAYNE PETER MERISOTIS S15Y1050. IN THE MATTER OF RUSS FLOYD BARNES S15Y1199. IN THE MATTER OF S. CARLTON ROUSE July 13, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S14G1192. DUBOIS et al. v. BRANTLEY et al. S14G1721. WELDON v. THE STATE S15A0082, S15X0083, S15A0626, S15X0627. BURTON et al. v. GLYNN COUNTY et al. (four cases) S15A0193. FROEHLICH v. FROEHLICH S15A0366. TIBBLES v. TEACHERS RETIREMENT SYSTEM OF GEORGIA et al. July 27, 2015 - SUMMARIES for NOTEWORTHY OPINIONS S15Y1099. IN THE MATTER OF TANYA YVETTE BROCKINGTON |